@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.4 2003/03/28 20:36:13 joern Exp $
+# $Id: Config.pm,v 1.42.2.5 2003/03/31 08:52:41 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -155,7 +155,7 @@ my %CONFIG_PARAMETER = (
 		],
 	},
 	burn_cdrecord_device => {
-		label => "cdrecord device (n,n,n)",
+		label => "cdrecord device (n,n,n or filename)",
 		type  => 'string',
 		value => '0,X,0',
 	},
@@ -533,7 +533,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.4 2003/03/28 20:36:13 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.5 2003/03/31 08:52:41 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -636,7 +636,7 @@ sub test_dvd_mount_point	{ _exists (@_)		}
 sub test_base_project_dir	{ _writable (@_)	}
 sub test_dvdrip_files_dir	{ _writable (@_)	}
 sub test_burn_writing_speed	{ _numeric (@_)		}
-sub test_burn_cdrecord_device	{ _device (@_)		}
+sub test_burn_cdrecord_device	{ _cdrecord_device (@_)	}
 sub test_burn_cdrecord_cmd   	{ _executable (@_) 	}
 sub test_burn_cdrdao_cmd   	{ _executable (@_) 	}
 sub test_burn_mkisofs_cmd   	{ _executable (@_) 	}
@@ -706,7 +706,7 @@ sub _numeric_or_empty {
 	return $self->_numeric ($name);
 }
 
-sub _device {
+sub _cdrecord_device {
 	my $self = shift;
 	my ($name) = @_;
 	
@@ -714,8 +714,10 @@ sub _device {
 
 	if ( $value =~ /^\d+,\d+,\d+$/ ) {
 		return "$value has format n,n,n : Ok";
+	} elsif ( -e $value ) {
+		return "$value exists : Ok\n";
 	} else {
-		return "$value has not format n,n,n : NOT Ok";
+		return "$value has not format n,n,n and is no file : NOT Ok";
 	}
 }
 
